==> zio-aws-rds_2.12-5.17.112.1-sources.jar: zio/aws/rds/model/DescribeDbLogFilesRequest.scala <==
package zio.aws.rds.model
import java.lang.Integer
import zio.aws.rds.model.primitives.IntegerOptional
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class DescribeDbLogFilesRequest(
    dbInstanceIdentifier: String,
    filenameContains: scala.Option[String] = None,
    fileLastWritten: scala.Option[Long] = None,
    fileSize: scala.Option[Long] = None,
    filters: scala.Option[Iterable[zio.aws.rds.model.Filter]] = None,
    maxRecords: scala.Option[IntegerOptional] = None,
    marker: scala.Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.rds.model.DescribeDbLogFilesRequest = {
    import DescribeDbLogFilesRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.rds.model.DescribeDbLogFilesRequest
      .builder()
      .dbInstanceIdentifier(dbInstanceIdentifier: java.lang.String)
      .optionallyWith(filenameContains.map(value => value: java.lang.String))(
        _.filenameContains
      )
      .optionallyWith(fileLastWritten.map(value => value: java.lang.Long))(
        _.fileLastWritten
      )
      .optionallyWith(fileSize.map(value => value: java.lang.Long))(_.fileSize)
      .optionallyWith(
        filters.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.filters)
      .optionallyWith(
        maxRecords.map(value => IntegerOptional.unwrap(value): Integer)
      )(_.maxRecords)
      .optionallyWith(marker.map(value => value: java.lang.String))(_.marker)
      .build()
  }
  def asReadOnly: zio.aws.rds.model.DescribeDbLogFilesRequest.ReadOnly =
    zio.aws.rds.model.DescribeDbLogFilesRequest.wrap(buildAwsValue())
}
object DescribeDbLogFilesRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.rds.model.DescribeDbLogFilesRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.rds.model.DescribeDbLogFilesRequest =
      zio.aws.rds.model.DescribeDbLogFilesRequest(
        dbInstanceIdentifier,
        filenameContains.map(value => value),
        fileLastWritten.map(value => value),
        fileSize.map(value => value),
        filters.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        maxRecords.map(value => value),
        marker.map(value => value)
      )
    def dbInstanceIdentifier: String
    def filenameContains: scala.Option[String]
    def fileLastWritten: scala.Option[Long]
    def fileSize: scala.Option[Long]
    def filters: scala.Option[List[zio.aws.rds.model.Filter.ReadOnly]]
    def maxRecords: scala.Option[IntegerOptional]
    def marker: scala.Option[String]
    def getDbInstanceIdentifier: ZIO[Any, Nothing, String] =
      ZIO.succeed(dbInstanceIdentifier)
    def getFilenameContains: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("filenameContains", filenameContains)
    def getFileLastWritten: ZIO[Any, AwsError, Long] =
      AwsError.unwrapOptionField("fileLastWritten", fileLastWritten)
    def getFileSize: ZIO[Any, AwsError, Long] =
      AwsError.unwrapOptionField("fileSize", fileSize)
    def getFilters
        : ZIO[Any, AwsError, List[zio.aws.rds.model.Filter.ReadOnly]] =
      AwsError.unwrapOptionField("filters", filters)
    def getMaxRecords: ZIO[Any, AwsError, IntegerOptional] =
      AwsError.unwrapOptionField("maxRecords", maxRecords)
    def getMarker: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("marker", marker)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.rds.model.DescribeDbLogFilesRequest
  ) extends zio.aws.rds.model.DescribeDbLogFilesRequest.ReadOnly {
    override val dbInstanceIdentifier: String =
      impl.dbInstanceIdentifier(): String
    override val filenameContains: scala.Option[String] =
      scala.Option(impl.filenameContains()).map(value => value: String)
    override val fileLastWritten: scala.Option[Long] =
      scala.Option(impl.fileLastWritten()).map(value => value: Long)
    override val fileSize: scala.Option[Long] =
      scala.Option(impl.fileSize()).map(value => value: Long)
    override val filters
        : scala.Option[List[zio.aws.rds.model.Filter.ReadOnly]] = scala
      .Option(impl.filters())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.rds.model.Filter.wrap(item)
        }.toList
      )
    override val maxRecords: scala.Option[IntegerOptional] = scala
      .Option(impl.maxRecords())
      .map(value => zio.aws.rds.model.primitives.IntegerOptional(value))
    override val marker: scala.Option[String] =
      scala.Option(impl.marker()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.rds.model.DescribeDbLogFilesRequest
  ): zio.aws.rds.model.DescribeDbLogFilesRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-rds_2.12-5.17.155.2-sources.jar: zio/aws/rds/model/DescribeDbLogFilesRequest.scala <==
package zio.aws.rds.model
import java.lang.Integer
import zio.aws.rds.model.primitives.IntegerOptional
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class DescribeDbLogFilesRequest(
    dbInstanceIdentifier: String,
    filenameContains: scala.Option[String] = None,
    fileLastWritten: scala.Option[Long] = None,
    fileSize: scala.Option[Long] = None,
    filters: scala.Option[Iterable[zio.aws.rds.model.Filter]] = None,
    maxRecords: scala.Option[IntegerOptional] = None,
    marker: scala.Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.rds.model.DescribeDbLogFilesRequest = {
    import DescribeDbLogFilesRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.rds.model.DescribeDbLogFilesRequest
      .builder()
      .dbInstanceIdentifier(dbInstanceIdentifier: java.lang.String)
      .optionallyWith(filenameContains.map(value => value: java.lang.String))(
        _.filenameContains
      )
      .optionallyWith(fileLastWritten.map(value => value: java.lang.Long))(
        _.fileLastWritten
      )
      .optionallyWith(fileSize.map(value => value: java.lang.Long))(_.fileSize)
      .optionallyWith(
        filters.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.filters)
      .optionallyWith(maxRecords.map(value => value: Integer))(_.maxRecords)
      .optionallyWith(marker.map(value => value: java.lang.String))(_.marker)
      .build()
  }
  def asReadOnly: zio.aws.rds.model.DescribeDbLogFilesRequest.ReadOnly =
    zio.aws.rds.model.DescribeDbLogFilesRequest.wrap(buildAwsValue())
}
object DescribeDbLogFilesRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.rds.model.DescribeDbLogFilesRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.rds.model.DescribeDbLogFilesRequest =
      zio.aws.rds.model.DescribeDbLogFilesRequest(
        dbInstanceIdentifier,
        filenameContains.map(value => value),
        fileLastWritten.map(value => value),
        fileSize.map(value => value),
        filters.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        maxRecords.map(value => value),
        marker.map(value => value)
      )
    def dbInstanceIdentifier: String
    def filenameContains: scala.Option[String]
    def fileLastWritten: scala.Option[Long]
    def fileSize: scala.Option[Long]
    def filters: scala.Option[List[zio.aws.rds.model.Filter.ReadOnly]]
    def maxRecords: scala.Option[IntegerOptional]
    def marker: scala.Option[String]
    def getDbInstanceIdentifier: ZIO[Any, Nothing, String] =
      ZIO.succeed(dbInstanceIdentifier)
    def getFilenameContains: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("filenameContains", filenameContains)
    def getFileLastWritten: ZIO[Any, AwsError, Long] =
      AwsError.unwrapOptionField("fileLastWritten", fileLastWritten)
    def getFileSize: ZIO[Any, AwsError, Long] =
      AwsError.unwrapOptionField("fileSize", fileSize)
    def getFilters
        : ZIO[Any, AwsError, List[zio.aws.rds.model.Filter.ReadOnly]] =
      AwsError.unwrapOptionField("filters", filters)
    def getMaxRecords: ZIO[Any, AwsError, IntegerOptional] =
      AwsError.unwrapOptionField("maxRecords", maxRecords)
    def getMarker: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("marker", marker)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.rds.model.DescribeDbLogFilesRequest
  ) extends zio.aws.rds.model.DescribeDbLogFilesRequest.ReadOnly {
    override val dbInstanceIdentifier: String =
      impl.dbInstanceIdentifier(): String
    override val filenameContains: scala.Option[String] =
      scala.Option(impl.filenameContains()).map(value => value: String)
    override val fileLastWritten: scala.Option[Long] =
      scala.Option(impl.fileLastWritten()).map(value => value: Long)
    override val fileSize: scala.Option[Long] =
      scala.Option(impl.fileSize()).map(value => value: Long)
    override val filters
        : scala.Option[List[zio.aws.rds.model.Filter.ReadOnly]] = scala
      .Option(impl.filters())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.rds.model.Filter.wrap(item)
        }.toList
      )
    override val maxRecords: scala.Option[IntegerOptional] =
      scala.Option(impl.maxRecords()).map(value => value: IntegerOptional)
    override val marker: scala.Option[String] =
      scala.Option(impl.marker()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.rds.model.DescribeDbLogFilesRequest
  ): zio.aws.rds.model.DescribeDbLogFilesRequest.ReadOnly = new Wrapper(impl)
}
